@@ -4,6 +4,7 @@ use crate::app::NodeFilter;
 use crate::app::NodeSorter;
 use crate::app::NodeSorterApplicable;
 use crate::ui::Border;
+use crate::ui::BorderType;
 use crate::ui::Constraint;
 use crate::ui::Layout;
 use crate::ui::Style;
@@ -233,6 +234,9 @@ pub struct GeneralConfig {
     #[serde(default)]
     pub hide_remaps_in_help_menu: bool,
 
+    #[serde(default)]
+    pub enforce_bounded_index_navigation: bool,
+
     #[serde(default)]
     pub prompt: UiElement,
 
@@ -302,7 +306,7 @@ pub struct KeyBindings {
 
     #[serde(default)]
     pub default: Option<Action>,
-    // Checklist for adding field:
+    // Checklist for adding new field:
     // - [ ] Update App::handle_key
     // - [ ] Update KeyBindings::sanitized
     // - [ ] Update Mode::help_menu
@@ -550,6 +554,9 @@ pub struct BuiltinModesConfig {
     #[serde(default)]
     pub rename: Mode,
 
+    #[serde(default)]
+    pub duplicate_as: Mode,
+
     #[serde(default)]
     pub delete: Mode,
 
@@ -595,6 +602,8 @@ impl BuiltinModesConfig {
             "go to" => Some(&self.go_to),
             "go_to" => Some(&self.go_to),
             "rename" => Some(&self.rename),
+            "duplicate as" => Some(&self.duplicate_as),
+            "duplicate_as" => Some(&self.duplicate_as),
             "delete" => Some(&self.delete),
             "action" => Some(&self.action),
             "search" => Some(&self.search),
@@ -642,18 +651,26 @@ pub struct PanelUiConfig {
     #[serde(default)]
     pub title: UiElement,
 
+    #[serde(default)]
+    pub style: Style,
+
     #[serde(default)]
     pub borders: Option<IndexSet<Border>>,
 
     #[serde(default)]
-    pub style: Style,
+    pub border_type: Option<BorderType>,
+
+    #[serde(default)]
+    pub border_style: Style,
 }
 
 impl PanelUiConfig {
     pub fn extend(mut self, other: &Self) -> Self {
         self.title = self.title.extend(&other.title);
-        self.borders = other.borders.to_owned().or(self.borders);
         self.style = self.style.extend(&other.style);
+        self.borders = other.borders.to_owned().or(self.borders);
+        self.border_type = other.border_type.to_owned().or(self.border_type);
+        self.border_style = self.border_style.extend(&other.border_style);
         self
     }
 }
@@ -716,15 +733,15 @@ impl LayoutsConfig {
 #[derive(Debug, Default, Clone, Serialize, Deserialize)]
 #[serde(deny_unknown_fields)]
 pub struct Config {
-    #[serde(default)]
-    pub layouts: LayoutsConfig,
-
     #[serde(default)]
     pub general: GeneralConfig,
 
     #[serde(default)]
     pub node_types: NodeTypesConfig,
 
+    #[serde(default)]
+    pub layouts: LayoutsConfig,
+
     #[serde(default)]
     pub modes: ModesConfig,
 }
